@@ -1,28 +1,16 @@
 #!/usr/bin/env python3
 """Not1MM Contest Contact Aggregation Server"""
 
-import logging
 import importlib
 import socket
-import time
 
 from time import gmtime, strftime
 
-import datetime
-
-# import os
 import sys
 
-# import threading
-# import argparse
 import queue
-
-# import pkgutil
-# from itertools import chain
 from json import JSONDecodeError, loads, dumps
 
-# from pathlib import Path
-# from shutil import copyfile
 # Import path may change depending on if it's dev or production.
 try:
     import renfield.lib.fsutils as fsutils
@@ -38,9 +26,6 @@ from textual.app import App, ComposeResult
 from textual.widgets import Static, Header, Footer, Placeholder, DataTable
 from textual.containers import VerticalScroll, Horizontal, Vertical, Grid, Container
 
-# from textual import log
-
-
 # pylint: disable=no-name-in-module, invalid-name, c-extension-no-member, global-statement
 
 
@@ -191,14 +176,17 @@ class Application(App):
     BINDINGS = [
         ("q", "quit_app", "Exit the application"),
         ("R", "reset_db", "Reset the database"),
+        ("Z", "zero_sn", "Zero out the serial number"),
+        ("c", "save_cabrillo", "Save Cabrillo"),
     ]
     contest = None
 
     def __init__(self):
         super().__init__()
-        self.DB: DataBase = DataBase("server_database.db", fsutils.HOME_PATH)
+        self.database: DataBase = DataBase("server_database.db", fsutils.HOME_PATH)
         self.active_contest: str | None = None
-        self.station: str | None = None
+        self.station: dict = {}
+        self.contest_settings: dict = {}
         self.contest: object | None = None
         self.operators_seen = {}
         self.udp_fifo: queue.Queue = queue.Queue()
@@ -235,12 +223,12 @@ class Application(App):
             with Horizontal(id="h1"):
                 yield Container(self.contestinfo, id="contestinfo")
                 yield Container(self.networkinfo, id="networkinfo")
-                yield Placeholder(id="ph5")
+                yield Placeholder(id="ph5", label="ToDo")
             with Horizontal(id="h2"):
                 yield Vertical(VerticalScroll(self.server_msg, id="scroll"), id="v1")
                 yield Vertical(
-                    Container(self.contactsinfo, id="ph1"),
-                    Container(self.operatorinfo, id="ph2"),
+                    Container(self.contactsinfo, id="contactsinfo"),
+                    Container(self.operatorinfo, id="operatorinfo"),
                     id="v2",
                 )
         yield Footer()
@@ -284,15 +272,15 @@ class Application(App):
         v1.styles.width = "2fr"
         v2.styles.width = "1fr"
 
-        ph1 = self.query_one("#ph1")
-        ph1.styles.height = "1fr"
-        ph1.styles.border = ("solid", "green")
-        ph1.border_title = "[blue]Contacts[/]"
+        contactsinfo = self.query_one("#contactsinfo")
+        contactsinfo.styles.height = "1fr"
+        contactsinfo.styles.border = ("solid", "green")
+        contactsinfo.border_title = "[blue]Contacts[/]"
 
-        ph2 = self.query_one("#ph2")
-        ph2.styles.height = "1fr"
-        ph2.styles.border = ("solid", "green")
-        ph2.border_title = "[blue]Operators[/]"
+        operatorinfo = self.query_one("#operatorinfo")
+        operatorinfo.styles.height = "1fr"
+        operatorinfo.styles.border = ("solid", "green")
+        operatorinfo.border_title = "[blue]Operators[/]"
 
         self.set_interval(0.2, self.server_message)
         self.set_interval(10.0, self.send_pulse)
@@ -300,15 +288,29 @@ class Application(App):
         self.update_contest_window()
         self.update_contacts_window()
 
+    def log_info(self, msg: str = "") -> None:
+        """send timestamped message to onscreen log"""
+        timestamp = strftime("%H:%M:%S", gmtime())
+        self.server_msg.on_update(f"\\[{timestamp}] {msg}")
+
     def action_quit_app(self) -> None:
         """Exit the application."""
         self.exit()
 
     def action_reset_db(self) -> None:
         """Reset the contest database."""
-        self.DB.reset_database()
+        self.log_info("Resetting DB")
+        self.database.reset_database()
         self.update_contacts_window()
 
+    def action_save_cabrillo(self) -> None:
+        """Save Cabrillo."""
+        self.contest.cabrillo(self, "utf-8")
+
+    def zero_sn(self) -> None:
+        """Zero out the serial number"""
+        self.database.wipe_sn_table()
+
     def send_pulse(self) -> None:
         """send heartbeat"""
         try:
@@ -317,7 +319,7 @@ class Application(App):
                 pulse, (self.MULTICAST_GROUP, self.MULTICAST_PORT)
             )
         except OSError as error:
-            logging.critical(f"OSError: {error}")
+            self.log_info(f"OSError: {error}")
 
         if self.active_contest is None:
             self.send_contest_request()
@@ -330,12 +332,11 @@ class Application(App):
                 pulse, (self.MULTICAST_GROUP, self.MULTICAST_PORT)
             )
         except OSError as error:
-            logging.critical(f"OSError: {error}")
+            self.log_info(f"OSError: {error}")
 
     def server_message(self) -> None:
         """Respond to network messages"""
 
-        timestamp = strftime("%H:%M:%S", gmtime())
         try:
             payload = self.network_socket.recv(2048)
         except socket.timeout:
@@ -355,62 +356,62 @@ class Application(App):
         print(json_data)
 
         if json_data.get("cmd") == "POST":
-            """
-            {
-                'TS': '2025-05-05 20:44:46',
-                'Call': 'K5TUX',
-                'Freq': 14030.0,
-                'QSXFreq': 14030.0,
-                'Mode': 'CW',
-                'ContestName': 'ARRL-FIELD-DAY',
-                'SNT': '599',
-                'RCV': '599',
-                'CountryPrefix': 'K',
-                'StationPrefix': 'K6GTE',
-                'QTH': '',
-                'Name': '',
-                'Comment': '',
-                'NR': 0,
-                'Sect': 'MO',
-                'Prec': '',
-                'CK': 0,
-                'ZN': 4,
-                'SentNr': 0,
-                'Points': 2,
-                'IsMultiplier1': 0,
-                'IsMultiplier2': 0,
-                'Power': 0,
-                'Band': '14',
-                'WPXPrefix': 'K5',
-                'Exchange1': '1B',
-                'RadioNR': '',
-                'ContestNR': '4',
-                'isMultiplier3': 0,
-                'MiscText': '',
-                'IsRunQSO': False,
-                'ContactType': '',
-                'Run1Run2': '',
-                'GridSquare': '',
-                'Operator': 'K6GTE',
-                'Continent': 'NA',
-                'RoverLocation': '',
-                'RadioInterfaced': '',
-                'NetworkedCompNr': 1,
-                'NetBiosName': 'fredo',
-                'IsOriginal': 1,
-                'ID': '42a30a19379b4171a810bb6b8ac4d9ce',
-                'CLAIMEDQSO': 1,
-                'cmd': 'POST',
-                'expire': '2025-05-05T13:45:16.061513'
-            }
-            """
-            self.server_msg.on_update(
-                f"\\[{timestamp}] CMD:{json_data.get('cmd', '')}:{json_data.get('Call', '')} From:{json_data.get('NetBiosName', '')}:{json_data.get('Operator', '')} "
+
+            # {
+            #     'TS': '2025-05-05 20:44:46',
+            #     'Call': 'K5TUX',
+            #     'Freq': 14030.0,
+            #     'QSXFreq': 14030.0,
+            #     'Mode': 'CW',
+            #     'ContestName': 'ARRL-FIELD-DAY',
+            #     'SNT': '599',
+            #     'RCV': '599',
+            #     'CountryPrefix': 'K',
+            #     'StationPrefix': 'K6GTE',
+            #     'QTH': '',
+            #     'Name': '',
+            #     'Comment': '',
+            #     'NR': 0,
+            #     'Sect': 'MO',
+            #     'Prec': '',
+            #     'CK': 0,
+            #     'ZN': 4,
+            #     'SentNr': 0,
+            #     'Points': 2,
+            #     'IsMultiplier1': 0,
+            #     'IsMultiplier2': 0,
+            #     'Power': 0,
+            #     'Band': '14',
+            #     'WPXPrefix': 'K5',
+            #     'Exchange1': '1B',
+            #     'RadioNR': '',
+            #     'ContestNR': '4',
+            #     'isMultiplier3': 0,
+            #     'MiscText': '',
+            #     'IsRunQSO': False,
+            #     'ContactType': '',
+            #     'Run1Run2': '',
+            #     'GridSquare': '',
+            #     'Operator': 'K6GTE',
+            #     'Continent': 'NA',
+            #     'RoverLocation': '',
+            #     'RadioInterfaced': '',
+            #     'NetworkedCompNr': 1,
+            #     'NetBiosName': 'fredo',
+            #     'IsOriginal': 1,
+            #     'ID': '42a30a19379b4171a810bb6b8ac4d9ce',
+            #     'CLAIMEDQSO': 1,
+            #     'cmd': 'POST',
+            #     'expire': '2025-05-05T13:45:16.061513'
+            # }
+
+            self.log_info(
+                f"CMD:{json_data.get('cmd', '')}:{json_data.get('Call', '')} From:{json_data.get('NetBiosName', '')}:{json_data.get('Operator', '')} "
             )
             json_data.pop("cmd", None)
             json_data.pop("expire", None)
 
-            self.DB.log_contact(json_data)
+            self.database.log_contact(json_data)
 
             packet = {"cmd": "RESPONSE"}
             packet["recipient"] = json_data.get("NetBiosName")
@@ -438,8 +439,19 @@ class Application(App):
             self.update_operators_window()
             return
 
+        if json_data.get("cmd") == "GET_SN":
+            next_sn = self.database.get_next_sn(json_data.get("Operator"))
+            packet = {"cmd": "RESPONSE"}
+            packet["recipient"] = json_data.get("NetBiosName")
+            packet["subject"] = "GET_SN"
+            packet["sn"] = next_sn
+            sendme = bytes(dumps(packet), encoding="ascii")
+            self.network_socket.sendto(
+                sendme, (self.MULTICAST_GROUP, self.MULTICAST_PORT)
+            )
+
         if json_data.get("cmd") == "LOG":
-            self.server_msg.on_update(f"Got {json_data.get("cmd")}: {json_data=} ")
+            self.log_info(f"Got {json_data.get("cmd")}: {json_data=} ")
             # LOG.add_item(f"[{timestamp}] GENERATE LOG: {json_data.get('station')}")
             # cabrillo()
             # packet = {"cmd": "RESPONSE"}
@@ -453,7 +465,7 @@ class Application(App):
             return
 
         if json_data.get("cmd") == "DUPE":
-            self.server_msg.on_update(f"Got {json_data.get("cmd")}: {json_data=} ")
+            self.log_info(f"Got {json_data.get("cmd")}: {json_data=} ")
             # LOG.add_item(f"[{timestamp}] Checking Dupe: {json_data.get('contact')}")
             # packet = {"cmd": "RESPONSE"}
             # packet["recipient"] = json_data.get("station")
@@ -470,11 +482,11 @@ class Application(App):
             return
 
         if json_data.get("cmd") == "DELETE":
-            self.server_msg.on_update(
-                f"\\[{timestamp}] CMD:{json_data.get('cmd', '')} From:{json_data.get('station', '')} ID:{json_data.get('ID', '')}"
+            self.log_info(
+                f"CMD:{json_data.get('cmd', '')} From:{json_data.get('station', '')} ID:{json_data.get('ID', '')}"
             )
 
-            self.DB.delete_contact(json_data.get("unique_id", ""))
+            self.database.delete_contact(json_data.get("unique_id", ""))
 
             packet = {"cmd": "RESPONSE"}
             packet["recipient"] = json_data.get("station")
@@ -488,8 +500,8 @@ class Application(App):
             return
 
         if json_data.get("cmd") == "CONTACTCHANGED":
-            self.server_msg.on_update(
-                f"\\[{timestamp}] CMD:{json_data.get('cmd', '')} From:{json_data.get('NetBiosName', '')} OP:{json_data.get('Operator', '')} ID:{json_data.get('ID', '')}"
+            self.log_info(
+                f"CMD:{json_data.get('cmd', '')} From:{json_data.get('NetBiosName', '')} OP:{json_data.get('Operator', '')} ID:{json_data.get('ID', '')}"
             )
             print(json_data)
             # Construct a response.
@@ -504,7 +516,7 @@ class Application(App):
             json_data.pop("expire", None)
             json_data.pop("unique_id", None)
 
-            self.DB.change_contact(json_data)
+            self.database.change_contact(json_data)
             sendme = bytes(dumps(packet), encoding="ascii")
             self.network_socket.sendto(
                 sendme, (self.MULTICAST_GROUP, self.MULTICAST_PORT)
@@ -527,17 +539,20 @@ class Application(App):
             # "Club": "", "IARUZone": 6, "CQZone": 3, "STXeq": "", "SPowe": "", "SAnte": "", "SAntH1": "",
             # "SAntH2": "", "RoverQTH": ""}}
 
-            self.server_msg.on_update(
-                f"\\[{timestamp}] CMD:{json_data.get('cmd', '')} From:{json_data.get('NetBiosName', '')} OP:{json_data.get('Operator', '')}"
+            self.log_info(
+                f"CMD:{json_data.get('cmd', '')} From:{json_data.get('NetBiosName', '')} OP:{json_data.get('Operator', '')}"
             )
             globals()["station"] = json_data.get("Station")
 
             self.active_contest = json_data.get("ContestName", "")
-            self.DB.current_contest = self.active_contest.upper().replace("_", "-")
+            # self.database.current_contest = self.active_contest.upper().replace(
+            #     "_", "-"
+            # )
             self.contest = doimp(json_data.get("ContestName"))
-            self.station = json_data.get("Station", {}).get("Call", "")
+            self.database.current_contest = self.contest.cabrillo_name
+            self.station = json_data.get("Station", {})
+            self.contest_settings = json_data
             self.update_contest_window()
-            self.server_msg.on_update("")
             self.update_contacts_window()
             print(f"Active contest set to {self.active_contest}")
             packet = {"cmd": "RESPONSE"}
@@ -552,9 +567,12 @@ class Application(App):
 
         if json_data.get("cmd") == "CURRENT_CONTEST":
             self.active_contest = json_data.get("ContestName", "")
-            self.DB.current_contest = self.active_contest.upper().replace("_", "-")
+            # self.database.current_contest = self.active_contest.upper().replace(
+            #     "_", "-"
+            # )
             self.server_msg.on_update("")
             self.contest = doimp(self.active_contest)
+            self.database.current_contest = self.contest.cabrillo_name
             self.update_contest_window()
             self.update_contacts_window()
             print(f"Active contest set to {self.active_contest}")
@@ -567,11 +585,13 @@ class Application(App):
 
     def update_contest_window(self) -> None:
         """Shows the contest information."""
-        self.contestinfo.on_update(self.station, self.active_contest, "")
+        self.contestinfo.on_update(
+            self.station.get("Call", ""), self.active_contest, ""
+        )
 
     def update_contacts_window(self) -> None:
         """Shows the contacts information."""
-        self.contactsinfo.on_update(self.DB.get_statistics())
+        self.contactsinfo.on_update(self.database.get_statistics())
 
     def update_operators_window(self) -> None:
         """
