@@ -28,6 +28,7 @@ class DataBase:
 
         self.database = app_data_dir + "/" + database
         self.create_dxlog_table()
+        self.create_sn_table()
 
     def reset_database(self):
         """Reset DataBase instance"""
@@ -37,6 +38,7 @@ class DataBase:
         except OSError:
             ...
         self.create_dxlog_table()
+        self.create_sn_table()
 
     @staticmethod
     def row_factory(cursor, row):
@@ -53,6 +55,49 @@ class DataBase:
             )
         }
 
+    def wipe_sn_table(self):
+        """wipes the SN table"""
+        print("Wiping SN Table")
+        try:
+            with sqlite3.connect(self.database) as conn:
+                cursor = conn.cursor()
+                sql_command = "DELETE FROM SN;"
+                cursor.execute(sql_command)
+        except sqlite3.OperationalError as exception:
+            print(f"{exception}")
+
+    def seed_sn(self, sn: int) -> None:
+        """seeds the starting serial number in the SN table"""
+
+        if sn is None:
+            return
+        print(f"Seeding SN Table with {sn}")
+        self.wipe_sn_table()
+        try:
+            with sqlite3.connect(self.database) as conn:
+                cursor = conn.cursor()
+                sql_command = "INSERT INTO SN (SerialNumber, Call) VALUES (?,?);"
+                cursor.execute(sql_command, (sn, "START"))
+                conn.commit()
+        except sqlite3.OperationalError as exception:
+            print(f"{exception}")
+
+    def create_sn_table(self) -> None:
+        """creates the sn table"""
+        print("Creating SN Table")
+        try:
+            with sqlite3.connect(self.database) as conn:
+                cursor = conn.cursor()
+                sql_command = (
+                    "CREATE TABLE IF NOT EXISTS SN ("
+                    "SerialNumber INTEGER DEFAULT 0, "
+                    "Call VARCHAR(15) NOT NULL, "
+                    "PRIMARY KEY (SerialNumber) );"
+                )
+                cursor.execute(sql_command)
+        except sqlite3.OperationalError as exception:
+            print(f"{exception}")
+
     def create_dxlog_table(self) -> None:
         """creates the dxlog table"""
         print("Creating DXLOG Table")
@@ -111,6 +156,40 @@ class DataBase:
         except sqlite3.OperationalError as exception:
             print(f"{exception}")
 
+    def get_next_sn(self, call: str) -> int | None:
+        """
+        Return next serial number.
+        Do this by getting the highest SerialNumber from the SN table and adding 1.
+        Then write this to the SN table with the call and return the serial number.
+        If no call given or call is not a string return None.
+        """
+        if not isinstance(call, str) or len(call) == 0:
+            return None
+        call = call.upper()
+        try:
+            with sqlite3.connect(self.database) as conn:
+                cursor = conn.cursor()
+                cursor.execute(f"SELECT count(*) from SN where Call = '{call}';")
+                call_exists = cursor.fetchone()[0]
+                cursor.execute("select max(SerialNumber) as highest from SN;")
+                highest = cursor.fetchone()[0]
+                if highest is None:
+                    highest = 0
+                highest += 1
+                if call_exists == 0:
+                    cursor.execute(
+                        f"insert into SN (SerialNumber, Call) values ({highest}, '{call}');"
+                    )
+                else:
+                    cursor.execute(
+                        f"update SN set SerialNumber = {highest} where Call = '{call}';"
+                    )
+                conn.commit()
+                return highest
+        except sqlite3.Error as exception:
+            print(f"DataBase get_next_sn: {exception}")
+            return None
+
     def log_contact(self, contact: dict) -> None:
         """
         Inserts a contact into the db.
