@@ -3,12 +3,8 @@
 # pylint: disable=invalid-name, unused-argument, unused-variable, c-extension-no-member, unused-import
 
 import datetime
-
 from pathlib import Path
 
-# from lib.plugin_common import gen_adif, get_points, online_score_xml
-# from lib.version import __version__
-
 # Import path may change depending on if it's dev or production.
 try:
     from lib.ham_utility import get_logged_band
@@ -24,7 +20,6 @@ name = "10 10 SUMMER PHONE"
 cabrillo_name = "10-10"
 mode = "SSB"  # CW SSB BOTH RTTY
 
-
 # 1 once per contest, 2 work each band, 3 each band/mode, 4 no dupe checking
 dupe_type = 1
 
@@ -71,9 +66,7 @@ def output_cabrillo_line(line_to_output, ending, file_descriptor, file_encoding)
 def cabrillo(self, file_encoding):
     """Generates Cabrillo file. Maybe."""
     # https://www.cqwpx.com/cabrillo.htm
-    # logger.debug("******Cabrillo*****")
-    # logger.debug("Station: %s", f"{self.station}")
-    # logger.debug("Contest: %s", f"{self.contest_settings}")
+
     now = datetime.datetime.now()
     date_time = now.strftime("%Y-%m-%d_%H-%M-%S")
     filename = (
@@ -81,7 +74,7 @@ def cabrillo(self, file_encoding):
         + "/"
         + f"{self.station.get('Call', '').upper()}_{cabrillo_name}_{date_time}.log"
     )
-    # logger.debug("%s", filename)
+    self.log_info(f"Saving log to:{filename}")
     log = self.database.fetch_all_contacts_asc()
     try:
         with open(filename, "w", encoding=file_encoding, newline="") as file_descriptor:
@@ -236,8 +229,10 @@ def cabrillo(self, file_encoding):
             for contact in log:
                 the_date_and_time = contact.get("TS", "")
                 themode = contact.get("Mode", "")
-                if themode == "LSB" or themode == "USB":
+                if themode in ("LSB", "USB", "FM"):
                     themode = "PH"
+                if themode in ("FT8", "FT4", "RTTY"):
+                    themode = "DG"
                 frequency = str(int(contact.get("Freq", "0"))).rjust(5)
 
                 loggeddate = the_date_and_time[:10]
@@ -255,7 +250,8 @@ def cabrillo(self, file_encoding):
                     file_encoding,
                 )
             output_cabrillo_line("END-OF-LOG:", "\r\n", file_descriptor, file_encoding)
-    except IOError:
+    except IOError as ioerror:
+        self.log_info(f"Error saving log: {ioerror}")
         return
 
 
