@@ -40,13 +40,8 @@
 
 
 import datetime
-
 from pathlib import Path
 
-
-# from not1mm_server.lib.plugin_common import gen_adif, get_points, online_score_xml
-# from not1mm_server.lib.version import __version__
-
 # Import path may change depending on if it's dev or production.
 try:
     from lib.ham_utility import get_logged_band
@@ -168,6 +163,7 @@ def cabrillo(self, file_encoding="utf-8"):
         + "/"
         + f"{self.station.get('Call', '').upper()}_{cabrillo_name}_{date_time}.log"
     )
+    self.log_info(f"Saving log to:{filename}")
     log = self.database.fetch_all_contacts_asc()
     try:
         with open(filename, "w", encoding=file_encoding, newline="") as file_descriptor:
@@ -322,7 +318,7 @@ def cabrillo(self, file_encoding="utf-8"):
             for contact in log:
                 the_date_and_time = contact.get("TS", "")
                 themode = contact.get("Mode", "")
-                if themode == "LSB" or themode == "USB":
+                if themode in ("LSB", "USB", "FM"):
                     themode = "PH"
                 frequency = str(int(contact.get("Freq", "0"))).rjust(5)
 
@@ -341,7 +337,8 @@ def cabrillo(self, file_encoding="utf-8"):
                     file_encoding,
                 )
             output_cabrillo_line("END-OF-LOG:", "\r\n", file_descriptor, file_encoding)
-    except IOError:
+    except IOError as ioerror:
+        self.log_info(f"Error saving log: {ioerror}")
         return
 
 
