@@ -23,15 +23,8 @@
 
 
 import datetime
-
 from pathlib import Path
 
-# from PyQt6 import QtWidgets
-
-# from not1mm.lib.plugin_common import gen_adif, get_points, online_score_xml
-# from not1mm.lib.version import __version__
-# from not1mm.lib.ham_utility import distance
-
 # Import path may change depending on if it's dev or production.
 try:
     from lib.ham_utility import get_logged_band
@@ -44,7 +37,6 @@ except (ImportError, ModuleNotFoundError):
 
 name = "DARC VHF"
 mode = "BOTH"  # CW SSB BOTH RTTY
-
 cabrillo_name = "DARC VHF"
 
 # 1 once per contest, 2 work each band, 3 each band/mode, 4 no dupe checking
@@ -416,6 +408,7 @@ def cabrillo(self, file_encoding):
         + "/"
         + f"{self.station.get('Call', '').upper()}_{cabrillo_name}_{date_time}.log"
     )
+    self.log_info(f"Saving log to:{filename}")
     log = self.database.fetch_all_contacts_asc()
     try:
         with open(filename, "w", encoding=file_encoding, newline="") as file_descriptor:
@@ -570,7 +563,7 @@ def cabrillo(self, file_encoding):
             for contact in log:
                 the_date_and_time = contact.get("TS", "")
                 themode = contact.get("Mode", "")
-                if themode == "LSB" or themode == "USB":
+                if themode in ("LSB", "USB", "FM"):
                     themode = "PH"
                 frequency = str(int(contact.get("Freq", "0"))).rjust(5)
 
@@ -589,7 +582,8 @@ def cabrillo(self, file_encoding):
                     file_encoding,
                 )
             output_cabrillo_line("END-OF-LOG:", "\r\n", file_descriptor, file_encoding)
-    except IOError:
+    except IOError as ioerror:
+        self.log_info(f"Error saving log: {ioerror}")
         return
 
 
