@@ -2,17 +2,21 @@
 
 # pylint: disable=invalid-name, unused-argument, unused-variable, c-extension-no-member, unused-import
 
+# Import path may change depending on if it's dev or production.
+try:
+    from lib.ham_utility import get_logged_band
+    from lib.plugin_common import gen_adif, get_points, online_score_xml
+    from lib.version import __version__
+except (ImportError, ModuleNotFoundError):
+    from renfield.lib.ham_utility import get_logged_band
+    from renfield.lib.plugin_common import gen_adif, get_points, online_score_xml
+    from renfield.lib.version import __version__
 
-# from not1mm.lib.ham_utility import get_logged_band
-from renfield.lib.plugin_common import gen_adif, get_points
-
-# from not1mm.lib.version import __version__
 
 name = "General Logging"
 cabrillo_name = "General-Logging"
 mode = "BOTH"  # CW SSB BOTH RTTY
 
-
 dupe_type = 4
 
 
@@ -48,12 +52,3 @@ def cabrillo(self, file_encoding):
 
 def recalculate_mults(self):
     """Recalculates multipliers after change in logged qso."""
-
-
-def check_call_history(self):
-    """"""
-    result = self.database.fetch_call_history(self.callsign.text())
-    if result:
-        self.history_info.setText(f"{result.get('UserText','')}")
-        if self.other_1.text() == "":
-            self.other_1.setText(f"{result.get('Name', '')}")
